==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Your_Account/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_EMAIL","qll");
define("_YES","O");
define("_NO","_");

define("_OPTIONAL","(D)");
define("_REQUIRED","()");
define("_SAVECHANGES","xs");
define("_THRESHOLD","e");
define("_NOCOMMENTS","ܷN");
define("_NESTED","_");
define("_FLAT","Z");
define("_THREAD","u");
define("_OLDEST","ª");
define("_NEWEST","s");
define("_HIGHEST","");


define("_ERRORINVEMAIL","~G~qll");
define("_ERROREMAILSPACES","~Gqlla}Ů");
define("_ERRORINVNICK","~G~nJW");
define("_NICK2LONG","nJWٹLAХέ^äoWL25Ӧr");
define("_NAMERESERVED","~GoOOdW");
define("_NICKNOSPACES","~GnJW٤oŮ");
define("_NICKTAKEN","~GnJW٤wQϥ");
define("_EMAILREGISTERED","~Gqlla}wQϥ");
define("_UUSERNAME","ϥΪ̦W");
define("_FINISH","");
define("_YOUUSEDEMAIL","zqllbwQϥ");
define("_TOREGISTER","еUb,");
define("_FOLLOWINGMEM","ϥΪ̸TG");
define("_UNICKNAME","-nJW١G");
define("_UPASSWORD","-KXG");
define("_USERPASS4","ϥΪ̱KX,Ω");
define("_YOUAREREGISTERED","AwgU, zKXNHzҶgqllb");
define("_THISISYOURPAGE","oOzӤH");
define("_AVATAR","H");
define("_WEBSITE","");
define("_ICQ","ICQ X");
define("_AIM","AIM X");
define("_YIM","YIM X");
define("_MSNM","MSNM X");
define("_LOCATION","m");
define("_OCCUPATION","¾~");
define("_INTERESTS","");
define("_SIGNATURE","ƦñW");
define("_MYHOMEPAGE","ڪG");
define("_MYEMAIL","ڪqllG");
define("_EXTRAINFO","LT");
define("_NOINFOFOR","{b|LT");
define("_LAST10COMMENTS","̪񪺤QNA");
define("_LAST10SUBMISSIONS","̪񪺤QsD뻼AѪ̬");
define("_LOGININCOR","nJ~IЭs...");
define("_USERLOGIN","ϥΪ̵nJ");
define("_USERREGLOGIN","ϥΪ̵U/nJ");
define("_REGNEWUSER","sϥΪ̵U");
define("_LIST","@");
define("_NEWUSER","sϥΪ");
define("_PASSWILLSEND","(KXNeܱzҿJqlla})");
define("_COOKIEWARNING","Gbn]wΨcookie");
define("_ASREGUSER","UϥΪvQG");
define("_ASREG1","αzWriK");
define("_ASREG2","αzWrHXsD");
define("_ASREG3","b@ӥiۤv]wӤHϰ");
define("_ASREG4","ܭsDܼƥ");
define("_ASREG5","վN");
define("_ASREG6","ܤPGDD");
define("_ASREG7","L@ǫܻŪ...");
define("_REGISTERNOW","{bUa!@KO!");
define("_WEDONTGIVE","ڭ̤|cάOѱzӤHTLH");
define("_ALLOWEMAILVIEW","\LϥΪ̬dݧڪqlla}");
define("_OPTION","ﶵ");
define("_PASSWORDLOST","ѤFzKXH");
define("_NOPROBLEM","SDAпJznJW٫AIHXsAڭ̱N|۰ʱHXzT{XzqllCzJznJWٻPT{XozsKXC");
define("_CONFIRMATIONCODE","T{X");
define("_SENDPASSWORD","HXKX");
define("_YOUARELOGGEDOUT","zwnXtΡI");
define("_SORRYNOUSERINFO","藍_A䤣ϥΪ̸T");
define("_USERACCOUNT","ϥΪ̱b");
define("_AT","");
define("_HASTHISEMAIL","qllP");
define("_AWEBUSERFROM","ϥΪ̡AӦ۩");
define("_HASREQUESTED","wnDHXKX");
define("_YOURNEWPASSWORD","zsKXOG");
define("_YOUCANCHANGE","bznJiק");
define("_IFYOUDIDNOTASK","pGzånDקKXAξߡAKXuziHAҥHzunηsKXnJYiC");
define("_UPDATEFAILED","LksϥΪ̵nOAp޲z");
define("_PASSWORD4","KXΩ");
define("_MAILED","wHX");
define("_CODEREQUESTED","wnDKXһݭnT{X");
define("_YOURCODEIS","zT{XOG");
define("_WITHTHISCODE","XiΩwsKX");
define("_IFYOUDIDNOTASK2","pGzånDקKXAξߡAЧRqll.");
define("_CODEFOR","T{XAΩ");
define("_USERPASSWORD4","ϥΪ̱KXAΩ");
define("_UREALNAME","W");
define("_UREALEMAIL","uqll");
define("_EMAILNOTPUBLIC","(qll󤣷|GATA]zKXNH즹b)");
define("_UFAKEMAIL","˹qll");
define("_EMAILPUBLIC","(qll|GAziHNw)");
define("_YOURHOMEPAGE","z");
define("_YOURAVATAR","z H");
define("_YICQ","z ICQ");
define("_YAIM","z AIM");
define("_YYIM","z YIM");
define("_YMSNM","z MSNM");
define("_YLOCATION","Ҧba");
define("_YOCCUPATION","z¾~");
define("_YINTERESTS","z");
define("_255CHARMAX","(̦h@ʭӦrAJzƦñWAHTML榡)");
define("_CANKNOWABOUT","(̦h@ʭӦr. Jz²)");
define("_TYPENEWPASSWORD","(קKXAпJsKX⦸)");
define("_SOMETHINGWRONG","ǲVõo...");
define("_PASSDIFFERENT","KXXAЭsJ");
define("_CHARLONG","줸ժ");
define("_AVAILABLEAVATARS","HM");
define("_NEWSINHOME","sDƥ");
define("_MAX127","(̦h. 127)G");
define("_ACTIVATEPERSONAL","ҰʭӤH");
define("_CHECKTHISOPTION","(ˬdﶵPܥ)");
define("_YOUCANUSEHTML","(ҦpAzi HTML өm쵲)");
define("_SELECTTHEME","ܤ@ӧGDD");
define("_THEMETEXT1","ﶵ|ק~[");
define("_THEMETEXT2","קuzͮ");
define("_THEMETEXT3","C@ӨϥΪ̯bݨ줣PGDD.");
define("_DISPLAYMODE","ܼҦ");
define("_SORTORDER","ƦC");
define("_COMMENTSWILLIGNORED","NƤp󥻳]wN");
define("_UNCUT","l");
define("_EVERYTHING","XG");
define("_FILTERMOSTANON","LoΦW");
define("_USCORE","");
define("_SCORENOTE","ΦW_l 0, W_l 1. HiW");
define("_NOSCORES","ä");
define("_HIDDESCORES","(äơG)");
define("_MAXCOMMENT","̤jת");
define("_TRUNCATES","(IhL, üW[Ū쵲. ]wȥ[췥jiϥ)");
define("_BYTESNOTE","줸 (1024 줸 = 1K)");
define("_USENDPRIVATEMSG","HXpHT");
define("_THEMESELECTION","GDD");
define("_COMMENTSCONFIG","պA");
define("_HOMECONFIG","պA");
define("_PERSONALINFO","ӤHT");
define("_USERSTATUS","ϥΪ̪A");
define("_ONLINE","su");
define("_OFFLINE","u");
define("_CHANGEYOURINFO","󴫱zT");
define("_CONFIGCOMMENTS","׳]w");
define("_CHANGEHOME","");
define("_LOGOUTEXIT","nX/}");
define("_SELECTTHETHEME","ܧGDD");
define("_PRIVATEMESSAGES","zpHT");
define("_EDITUSER","sϥΪ");
define("_RECEIVENEWSLETTER"," Email ql?");
define("_NOTSUBSCRIBED","p, zLk[Jڭ̪ql");
define("_SUBSCRIBED","zwgq\ql.");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Your_Account/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_EMAIL","qll");
define("_YES","O");
define("_NO","_");

define("_OPTIONAL","(D)");
define("_REQUIRED","()");
define("_SAVECHANGES","xs");
define("_THRESHOLD","e");
define("_NOCOMMENTS","ܷN");
define("_NESTED","_");
define("_FLAT","Z");
define("_THREAD","u");
define("_OLDEST","ª");
define("_NEWEST","s");
define("_HIGHEST","");


define("_ERRORINVEMAIL","~G~qll");
define("_ERROREMAILSPACES","~Gqlla}Ů");
define("_ERRORINVNICK","~G~nJW");
define("_NICK2LONG","nJWٹLAХέ^äoWL25Ӧr");
define("_NAMERESERVED","~GoOOdW");
define("_NICKNOSPACES","~GnJW٤oŮ");
define("_NICKTAKEN","~GnJW٤wQϥ");
define("_EMAILREGISTERED","~Gqlla}wQϥ");
define("_UUSERNAME","ϥΪ̦W");
define("_FINISH","");
define("_YOUUSEDEMAIL","zqllbwQϥ");
define("_TOREGISTER","еUb,");
define("_FOLLOWINGMEM","ϥΪ̸TG");
define("_UNICKNAME","-nJW١G");
define("_UPASSWORD","-KXG");
define("_USERPASS4","ϥΪ̱KX,Ω");
define("_YOUAREREGISTERED","AwgU, zKXNHzҶgqllb");
define("_THISISYOURPAGE","oOzӤH");
define("_AVATAR","H");
define("_WEBSITE","");
define("_ICQ","ICQ X");
define("_AIM","AIM X");
define("_YIM","YIM X");
define("_MSNM","MSNM X");
define("_LOCATION","m");
define("_OCCUPATION","¾~");
define("_INTERESTS","");
define("_SIGNATURE","ƦñW");
define("_MYHOMEPAGE","ڪG");
define("_MYEMAIL","ڪqllG");
define("_EXTRAINFO","LT");
define("_NOINFOFOR","{b|LT");
define("_LAST10COMMENTS","̪񪺤QNA");
define("_LAST10SUBMISSIONS","̪񪺤QsD뻼AѪ̬");
define("_LOGININCOR","nJ~IЭs...");
define("_USERLOGIN","ϥΪ̵nJ");
define("_USERREGLOGIN","ϥΪ̵U/nJ");
define("_REGNEWUSER","sϥΪ̵U");
define("_LIST","@");
define("_NEWUSER","sϥΪ");
define("_PASSWILLSEND","(KXNeܱzҿJqlla})");
define("_COOKIEWARNING","Gbn]wΨcookie");
define("_ASREGUSER","UϥΪvQG");
define("_ASREG1","αzWriK");
define("_ASREG2","αzWrHXsD");
define("_ASREG3","b@ӥiۤv]wӤHϰ");
define("_ASREG4","ܭsDܼƥ");
define("_ASREG5","վN");
define("_ASREG6","ܤPGDD");
define("_ASREG7","L@ǫܻŪ...");
define("_REGISTERNOW","{bUa!@KO!");
define("_WEDONTGIVE","ڭ̤|cάOѱzӤHTLH");
define("_ALLOWEMAILVIEW","\LϥΪ̬dݧڪqlla}");
define("_OPTION","ﶵ");
define("_PASSWORDLOST","ѤFzKXH");
define("_NOPROBLEM","SDAпJznJW٫AIHXsAڭ̱N|۰ʱHXzT{XzqllCzJznJWٻPT{XozsKXC");
define("_CONFIRMATIONCODE","T{X");
define("_SENDPASSWORD","HXKX");
define("_YOUARELOGGEDOUT","zwnXtΡI");
define("_SORRYNOUSERINFO","藍_A䤣ϥΪ̸T");
define("_USERACCOUNT","ϥΪ̱b");
define("_AT","");
define("_HASTHISEMAIL","qllP");
define("_AWEBUSERFROM","ϥΪ̡AӦ۩");
define("_HASREQUESTED","wnDHXKX");
define("_YOURNEWPASSWORD","zsKXOG");
define("_YOUCANCHANGE","bznJiק");
define("_IFYOUDIDNOTASK","pGzånDקKXAξߡAKXuziHAҥHzunηsKXnJYiC");
define("_UPDATEFAILED","LksϥΪ̵nOAp޲z");
define("_PASSWORD4","KXΩ");
define("_MAILED","wHX");
define("_CODEREQUESTED","wnDKXһݭnT{X");
define("_YOURCODEIS","zT{XOG");
define("_WITHTHISCODE","XiΩwsKX");
define("_IFYOUDIDNOTASK2","pGzånDקKXAξߡAЧRqll.");
define("_CODEFOR","T{XAΩ");
define("_USERPASSWORD4","ϥΪ̱KXAΩ");
define("_UREALNAME","W");
define("_UREALEMAIL","uqll");
define("_EMAILNOTPUBLIC","(qll󤣷|GATA]zKXNH즹b)");
define("_UFAKEMAIL","˹qll");
define("_EMAILPUBLIC","(qll|GAziHNw)");
define("_YOURHOMEPAGE","z");
define("_YOURAVATAR","z H");
define("_YICQ","z ICQ");
define("_YAIM","z AIM");
define("_YYIM","z YIM");
define("_YMSNM","z MSNM");
define("_YLOCATION","Ҧba");
define("_YOCCUPATION","z¾~");
define("_YINTERESTS","z");
define("_255CHARMAX","(̦h@ʭӦrAJzƦñWAHTML榡)");
define("_CANKNOWABOUT","(̦h@ʭӦr. Jz²)");
define("_TYPENEWPASSWORD","(קKXAпJsKX⦸)");
define("_SOMETHINGWRONG","ǲVõo...");
define("_PASSDIFFERENT","KXXAЭsJ");
define("_CHARLONG","줸ժ");
define("_AVAILABLEAVATARS","HM");
define("_NEWSINHOME","sDƥ");
define("_MAX127","(̦h. 127)G");
define("_ACTIVATEPERSONAL","ҰʭӤH");
define("_CHECKTHISOPTION","(ˬdﶵPܥ)");
define("_YOUCANUSEHTML","(ҦpAzi HTML өm쵲)");
define("_SELECTTHEME","ܤ@ӧGDD");
define("_THEMETEXT1","ﶵ|ק~[");
define("_THEMETEXT2","קuzͮ");
define("_THEMETEXT3","C@ӨϥΪ̯bݨ줣PGDD.");
define("_DISPLAYMODE","ܼҦ");
define("_SORTORDER","ƦC");
define("_COMMENTSWILLIGNORED","NƤp󥻳]wN");
define("_UNCUT","l");
define("_EVERYTHING","XG");
define("_FILTERMOSTANON","LoΦW");
define("_USCORE","");
define("_SCORENOTE","ΦW_l 0, W_l 1. HiW");
define("_NOSCORES","ä");
define("_HIDDESCORES","(äơG)");
define("_MAXCOMMENT","̤jת");
define("_TRUNCATES","(IhL, üW[Ū쵲. ]wȥ[췥jiϥ)");
define("_BYTESNOTE","줸 (1024 줸 = 1K)");
define("_USENDPRIVATEMSG","HXpHT");
define("_THEMESELECTION","GDD");
define("_COMMENTSCONFIG","պA");
define("_HOMECONFIG","պA");
define("_PERSONALINFO","ӤHT");
define("_USERSTATUS","ϥΪ̪A");
define("_ONLINE","su");
define("_OFFLINE","u");
define("_CHANGEYOURINFO","󴫱zT");
define("_CONFIGCOMMENTS","׳]w");
define("_CHANGEHOME","");
define("_LOGOUTEXIT","nX/}");
define("_SELECTTHETHEME","ܧGDD");
define("_PRIVATEMESSAGES","zpHT");
define("_EDITUSER","sϥΪ");
define("_RECEIVENEWSLETTER"," Email ql?");
define("_NOTSUBSCRIBED","p, zLk[Jڭ̪ql");
define("_SUBSCRIBED","zwgq\ql.");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>
